import md5

from django import template

register = template.Library()

@register.simple_tag
def mediahash(name):
	return dohash(name)

def dohash(name):
	from django.conf import settings
	if settings.DEBUG:
		return "%s/%s" % (settings.MEDIA_URL, name)
	else:
		try:
			from django.conf import settings
		except ImportError:
			return ''
		m = md5.new()
		m.update(name)
		h = m.hexdigest()
		number = int(h, 16) % settings.MEDIA_HASH_RANGE + 1
		return "%s/%s" % (settings.MEDIA_HASH_URL % number, name)



#!/usr/bin/env python

from setuptools import setup, find_packages

setup(name='glamkit-performance',
    version='0.5.1',
    description='A template tag to help with concurrent media serving from Django',
    author='Thomas Ashelford',
    author_email='thomas@interaction.net.au',
    url='http://glamkit.org/',
    packages=find_packages(),
    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ]
)